############
django radio
############

A radio management application that makes easy scheduling, live recording, publishing...

It is used by `RadioCo  <https://github.com/iago1460/radioco>`_.

********
Features
********

* designed to work with any web browser
* drag and drop scheduling calendar interface
* live shows can be recorded and published automatically
* complete authentication system (user accounts, groups, permissions)

* ...and much more

More information on `our website <http://radioco.org/>`_.

*************
Documentation
*************

Please head over to our `documentation <http://django-radio.readthedocs.org/>`_ for all
the details on how to install, extend and use django radio.

***********
Quick Start
***********

We recommend using a `configured radioco project  <https://github.com/iago1460/radioco>`_.
